==> haskell-storable-tuple-0.0.3.3-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storable-tuple
version:              0.0.3.3
visibility:           public
id:                   storable-tuple-0.0.3.3-50HFnBwCK5kBH3z0ICXsy5
key:                  storable-tuple-0.0.3.3-50HFnBwCK5kBH3z0ICXsy5
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storable@henning-thielemann.de>
author:               Henning Thielemann <storable@henning-thielemann.de>
stability:            Experimental
homepage:             http://code.haskell.org/~thielema/storable-tuple/
synopsis:             Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.

category:             Data, Foreign
abi:                  1e287f4adba8836bbd5841d76a93c26c
exposed:              True
exposed-modules:      Foreign.Storable.Tuple
import-dirs:          /usr/lib/ghc-8.10.2/site-local/storable-tuple-0.0.3.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/storable-tuple-0.0.3.3
hs-libraries:         HSstorable-tuple-0.0.3.3-50HFnBwCK5kBH3z0ICXsy5
depends:
    base-4.14.1.0 base-orphans-0.8.3-KlGpQp7QlHX2MNUo6ZGksw
    storable-record-0.0.5-FsUJklA2neMEEf5VH5VYBz
    utility-ht-0.0.15-6t9XaVETW59JixBl5tu1ZP

haddock-interfaces:
    /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock

haddock-html:         /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-tuple-0.0.3.3-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storable-tuple
version:              0.0.3.3
visibility:           public
id:                   storable-tuple-0.0.3.3-DzVuXKaES2lDH5JszhR6iD
key:                  storable-tuple-0.0.3.3-DzVuXKaES2lDH5JszhR6iD
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storable@henning-thielemann.de>
author:               Henning Thielemann <storable@henning-thielemann.de>
stability:            Experimental
homepage:             http://code.haskell.org/~thielema/storable-tuple/
synopsis:             Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.

category:             Data, Foreign
abi:                  9815facacc60d59c76e243f73981b10a
exposed:              True
exposed-modules:      Foreign.Storable.Tuple
import-dirs:          /usr/lib/ghc-8.10.3/site-local/storable-tuple-0.0.3.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/storable-tuple-0.0.3.3
hs-libraries:         HSstorable-tuple-0.0.3.3-DzVuXKaES2lDH5JszhR6iD
depends:
    base-4.14.1.0 base-orphans-0.8.4-IGWpT0teY3i5Jtd70zZv4R
    storable-record-0.0.5-FsUJklA2neMEEf5VH5VYBz
    utility-ht-0.0.15-6t9XaVETW59JixBl5tu1ZP

haddock-interfaces:
    /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock

haddock-html:         /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
